@@ -1,10 +1,7 @@
 # coding: utf-8
 from django.conf import settings
 
-try:
-    from m3.core.middleware import get_thread_data
-except ImportError:
-    from m3_legacy.middleware import get_thread_data
+from m3_legacy.middleware import get_thread_data
 
 __author__ = 'Andrey Torsunov'
 __contact__ = 'torsunov@bars-open.com'
